## v0.1.1 (2025-04-24)

### Fix

- **plotting**: update plotting and interaciton to be more pythonic

## v0.1.0 (2025-04-24)

### Feat

- **initial-construction**: nexafs accessor to process nexafs in python
